summaryrefslogtreecommitdiffstats
path: root/btif/include
diff options
context:
space:
mode:
authorKausik Sinnaswamy <kausik@broadcom.com>2012-03-06 13:07:54 -0800
committerMatthew Xie <mattx@google.com>2012-07-14 11:19:11 -0700
commite2f1686eb6870338e070714a75bb5c7266440faf (patch)
treef548a9daef06cfed2a16b978076e2ff48fc4447f /btif/include
parent6244405bed75853e51324d1f7c90548ba15321b5 (diff)
downloadexternal_bluetooth_bluedroid-e2f1686eb6870338e070714a75bb5c7266440faf.zip
external_bluetooth_bluedroid-e2f1686eb6870338e070714a75bb5c7266440faf.tar.gz
external_bluetooth_bluedroid-e2f1686eb6870338e070714a75bb5c7266440faf.tar.bz2
Merged the Passkey request callback and the passkey reply APIs into the SSP API and callback respectively
Change-Id: I356e2bea421377e68b8702404a989634f2445efa
Diffstat (limited to 'btif/include')
-rw-r--r--btif/include/btif_api.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/btif/include/btif_api.h b/btif/include/btif_api.h
index 5ceb197..b5157de 100644
--- a/btif/include/btif_api.h
+++ b/btif/include/btif_api.h
@@ -330,14 +330,15 @@ bt_status_t btif_dm_passkey_reply( const bt_bdaddr_t *bd_addr,
**
** Function btif_dm_ssp_reply
**
** Description BT SSP Reply - Just Works & Numeric Comparison
**
** Returns bt_status_t
**
*******************************************************************************/
bt_status_t btif_dm_ssp_reply( const bt_bdaddr_t *bd_addr,
- uint8_t accept);
+ bt_ssp_variant_t variant, uint8_t accept,
+ uint32_t passkey);
/*******************************************************************************
**
@@ -330,14 +330,15 @@ bt_status_t btif_dm_passkey_reply( const bt_bdaddr_t *bd_addr,
** Function btif_dm_ssp_reply
**
-** Description BT SSP Reply - Just Works & Numeric Comparison
+** Description BT SSP Reply - Just Works, Numeric Comparison & Passkey Entry
**
** Returns bt_status_t